@@ -62,8 +62,10 @@ module Linguist
       node_modules? ||
       go_vendor? ||
       go_lock? ||
+      poetry_lock? ||
       esy_lock? ||
       npm_shrinkwrap_or_package_lock? ||
+      generated_yarn_plugnplay? ||
       godeps? ||
       generated_by_zephir? ||
       minified_files? ||
@@ -95,7 +97,9 @@ module Linguist
       generated_gamemakerstudio? ||
       generated_gimp? ||
       generated_visualstudio6? ||
-      generated_haxe?
+      generated_haxe? ||
+      generated_jooq? ||
+      generated_pascal_tlb?
     end
 
     # Internal: Is the blob an Xcode file?
@@ -237,7 +241,7 @@ module Linguist
     #
     # Returns true or false
     def generated_net_designer_file?
-      name.downcase =~ /\.designer\.(cs|vb)$/
+      !!name.match(/\.designer\.(cs|vb)$/i)
     end
 
     # Internal: Is this a codegen file for Specflow feature file?
@@ -248,7 +252,7 @@ module Linguist
     #
     # Returns true or false
     def generated_net_specflow_feature_file?
-      name.downcase =~ /\.feature\.cs$/
+      !!name.match(/\.feature\.cs$/i)
     end
 
     # Internal: Is the blob of JS a parser generated by PEG.js?
@@ -301,10 +305,10 @@ module Linguist
       return false unless extname == '.go'
       return false unless lines.count > 1
 
-      return lines.first(10).any? { |l| l.include? "Code generated by" }
+      return lines.first(40).any? { |l| l.include? "Code generated by" }
     end
 
-    PROTOBUF_EXTENSIONS = ['.py', '.java', '.h', '.cc', '.cpp', '.m', '.rb']
+    PROTOBUF_EXTENSIONS = ['.py', '.java', '.h', '.cc', '.cpp', '.m', '.rb', '.php']
 
     # Internal: Is the blob a C++, Java or Python source file generated by the
     # Protocol Buffer compiler?
@@ -314,7 +318,7 @@ module Linguist
       return false unless PROTOBUF_EXTENSIONS.include?(extname)
       return false unless lines.count > 1
 
-      return lines[0].include?("Generated by the protocol buffer compiler.  DO NOT EDIT!")
+      return lines.first(3).any? { |l| l.include?("Generated by the protocol buffer compiler.  DO NOT EDIT!") }
     end
 
     # Internal: Is the blob a Javascript source file generated by the
@@ -371,6 +375,13 @@ module Linguist
       !!name.match(/(Gopkg|glide)\.lock/)
     end
 
+    # Internal: Is the blob a generated poetry.lock?
+    #
+    # Returns true or false.
+    def poetry_lock?
+      !!name.match(/poetry\.lock/)
+    end
+
     # Internal: Is the blob a generated esy lock file?
     #
     # Returns true or false.
@@ -382,7 +393,14 @@ module Linguist
     #
     # Returns true or false.
     def npm_shrinkwrap_or_package_lock?
-      name.match(/npm-shrinkwrap\.json/) || name.match(/package-lock\.json/)
+      !!name.match(/npm-shrinkwrap\.json/) || !!name.match(/package-lock\.json/)
+    end
+
+    # Internal: Is the blob a generated Yarn Plug'n'Play?
+    #
+    # Returns true or false.
+    def generated_yarn_plugnplay?
+      !!name.match(/(^|\/)\.pnp\.(c|m)?js$/)
     end
 
     # Internal: Is the blob part of Godeps/,
@@ -441,7 +459,7 @@ module Linguist
     #
     # Returns true or false.
     def pipenv_lock?
-      name.match(/Pipfile\.lock/)
+      !!name.match(/Pipfile\.lock/)
     end
 
     # Internal: Is it a KiCAD or GFortran module file?
@@ -683,6 +701,24 @@ module Linguist
       end
     end
 
+    # Internal: Is this a generated jOOQ file?
+    #
+    # Return true or false
+    def generated_jooq?
+      return false unless extname.downcase == '.java'
+      lines.first(2).any? { |l| l.include? 'This file is generated by jOOQ.' }
+    end
+
+    # Internal: Is this a generated Delphi Interface file for a type library?
+    #
+    # Delphi Type Library Import tool generates *_TLB.pas files based on .ridl files.
+    # They are not meant to be altered by humans.
+    #
+    # Returns true or false
+    def generated_pascal_tlb?
+      !!name.match(/_tlb\.pas$/i)
+    end
+
     # Internal: Extract a Hash of name/content pairs from an HTML <meta> tag
     def extract_html_meta(match)
       (match.last.sub(/\/\Z/, "").strip.scan(/
